@@ -1,7 +1,7 @@
 import ctypes
 
 # Load the shared library
-lib = ctypes.CDLL('./a.so')
+lib = ctypes.CDLL('a.so')
 
 # Define the argument and return types of the function
 lib.add.argtypes = [ctypes.c_int, ctypes.c_int]
